| Title: | Mathematical Formulas and Character Recognition |
|---|---|
| Description: | By calling the 'SimpleTex' <https://simpletex.cn/> open API implements text and mathematical formula recognition on the image, and the output formula can be used directly with 'Markdown' and 'LaTeX'. |
| Authors: | Xinyuan Chu [aut, cre] |
| Maintainer: | Xinyuan Chu <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.5 |
| Built: | 2026-05-17 05:34:49 UTC |
| Source: | https://github.com/chuxinyuan/simpletex |
Mathematical formulas and character recognition.
imgocr(img, mode = "latex_ocr")imgocr(img, mode = "latex_ocr")
img |
An image file, supporting jpg, png, bmp format. |
mode |
Set service model. The value can be 'latex_ocr', 'latex_ocr_turbo', or 'simpletex_ocr'. The default value is 'latex_ocr'. The 'latex_ocr' and 'latex_ocr_turbo' are used for formula identification. 'latex_ocr' is better than 'latex_ocr_turbo', but 'latex_ocr_turbo' is faster. 'simpletex_ocr' is suitable for general image recognition. |
Text or mathematical formulas for Markdown and LaTeX.
## Not run: imgocr("path/to/test.jpg") imgocr("path/to/test.png", mode = "latex_ocr_turbo") imgocr("path/to/test.bmp", mode = "simpletex_ocr") ## End(Not run)## Not run: imgocr("path/to/test.jpg") imgocr("path/to/test.png", mode = "latex_ocr_turbo") imgocr("path/to/test.bmp", mode = "simpletex_ocr") ## End(Not run)